// LibAvWrap -- .NET wrapper for the libav* libraries
// --------------------------------------------------
// By Christian Richardt <christian@richardt.name>
// (based on AvDn 0.7, www.informikon.com/tutorials/)
//
// $Id: OutputFormat.h 436 2010-10-15 16:26:38Z cr333 $

#pragma once

using namespace System;
using namespace System::Text;
using namespace System::Runtime::InteropServices;

extern "C" {
#include "libavformat/avformat.h"
}

#include "Enums.h"
#include "Wrapper.h"

namespace LibAvWrap
{
	///<summary>Wrapper for the AVOutputFormat structure.</summary>
	public ref class LibAvOutputFormat : Wrapper<AVOutputFormat>
	{
// constructors and destructor --------------------------------------------------------------------

	internal:
		///<summary>Construct from a given native pointer.</summary>
		LibAvOutputFormat(AVOutputFormat* p) : Wrapper<AVOutputFormat>(p) { };
	
	public:
		///<summary>Construct from a given native address.</summary>
		LibAvOutputFormat(IntPtr ptr) : Wrapper<AVOutputFormat>(ptr) { };

	public:
		///<summary>Destructor.</summary>
		~LibAvOutputFormat() { }

// member functions -------------------------------------------------------------------------------

// properties -------------------------------------------------------------------------------------

		///<summary>Flags.</summary>
		// TODO: should be enum
		property int Flags {
			int get() { return pointer->flags; }
		}

		///<summary>The long name of the output format.</summary>
		property String^ LongName {
			String^ get() { return Marshal::PtrToStringAnsi(IntPtr((void*)(pointer->long_name))); }
		}

		///<summary>The mime type of the output format.</summary>
		property String^ MimeType {
			String^ get() { return Marshal::PtrToStringAnsi(IntPtr((void*)(pointer->mime_type))); }
		}

		///<summary>The short name of the output format.</summary>
		property String^ Name {
			String^ get() { return Marshal::PtrToStringAnsi(IntPtr((void*)(pointer->name))); }
		}

		///<summary>The audio codec of the output format.</summary>
		property LibAvWrap::CodecID AudioCodec {
			LibAvWrap::CodecID get() { return (LibAvWrap::CodecID)(int)pointer->audio_codec; }
		}

		///<summary>The video codec of the output format.</summary>
		property LibAvWrap::CodecID VideoCodec {
			LibAvWrap::CodecID get() { return (LibAvWrap::CodecID)(int)pointer->video_codec; }
		}
	};

} // namespace LibAvWrap