﻿// $Id: PassThroughFilter.cs 533 2011-05-11 17:41:42Z cr333 $
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;

namespace VideoLib.OpenGL
{
	// OpenGL rendering passes are executed asynchronously by the GPU and OpenGL nodes hence can
	// return before their last rendering pass has completed. This causes the reported runtime of
	// a node to be lower than it actually is, as part of it is 'moved' to the next node in the
	// pipeline, which will wait for the texture rendered by the previous node to become available.

	/// <summary>Copies the input texture to the output. Useful for timing.</summary>
	public class PassThroughFilter : FboNode
	{
		/// <summary>Initialises a new instance of the <see cref="PassThroughFilter"/> class.</summary>
		public PassThroughFilter()
		{
			AddDefaultPins();
		}

		/// <summary>Initialises the OpenGL state.</summary>
		public override void Init()
		{
			// load, compile and link shaders
			programID = Utils.LinkShaders(
				Utils.CreateShaderFromResource("Shaders.PassThroughFilter.frag")
			);

			// map textures
			textureMap = new List<TextureBinding> {
				new TextureBinding { Pin = "in", Uniform = "input", Unit = 0 },
			};

			base.Init();
		}

		/// <summary>Draws to the framebuffer object using the given input textures.</summary>
		/// <param name="inputs">The input textures.</param>
		/// <returns>The resulting texture.</returns>
		public override TextureFrame Draw(Dictionary<string, TextureFrame> inputs)
		{
			// allocate a texture that is identical to the input
			var resultTexture = TextureFrame.CreateToMatch(inputs["in"]);
			resultTexture.Alloc();

			Draw(inputs, resultTexture.Texture);

			return resultTexture;
		}
	}
}
