/*
This source code is part of the Floating Textures test program, which
is a derivative of the complete Floating Textures program containing
the offline version with prereconstructed geometry and prerecorded
video. 
For more information on Floating Textures please have a look at the article

"Floating Textures" 
by M. Eisemann, B. De Decker, M. Magnor, 
P. Bekaert, E. de Aguiar, N. Ahmed, C. Theobalt, A. Sellent
Computer Graphics Forum (Proc. Eurographics EG'08), vol. 27, no. 2, April 2008 


Copyright (C) 2008 Martin Eisemann

This program is free software; you can redistribute it and/or modify it under 
the terms of the GNU General Public License as published by the Free Software 
Foundation; either version 3 of the License, or (at your option) any later 
version.

This program is distributed in the hope that it will be useful, but WITHOUT 
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with 
this program; if not, see <http://www.gnu.org/licenses/>.
*/

/**
 * \file UpdateUV.frag
 *
 * \brief Updates the given Optical Flow Field UV by adding the newly computed difference DUV. Resets DUV afterwards
 *
 */

// enable draw_buffers //
#extension GL_ARB_draw_buffers : enable

uniform sampler2D texUVField;
uniform sampler2D texDUVField;

void main()
{
  vec2 texCoord  = gl_TexCoord[0].xy;

  vec4 UV  = texture2D(texUVField,  texCoord);
  vec4 DUV = texture2D(texDUVField, texCoord);

  gl_FragData[0] = UV + DUV; // update uv flow field
  gl_FragData[1] = vec4(0.0, 0.0, 0.0, 0.0); // reset duv flow field

} 
