﻿// $Id: UniformAttribute.cs 505 2010-11-26 16:37:26Z cr333 $
using System;

namespace VideoLib.OpenGL
{
	/// <summary>Attribute that marks uniforms to be used in shaders.</summary>
	[AttributeUsage(AttributeTargets.Property, Inherited = false, AllowMultiple = true)]
	public sealed class UniformAttribute : Attribute
	{
		/// <summary>Initialises a new instance of the <see cref="UniformAttribute"/> class.</summary>
		public UniformAttribute()
		{
			this.name = "";
			this.Unit = 0;
		}

		/// <summary>Initialises a new instance of the <see cref="UniformAttribute"/> class. Use if the uniform name is different to the property name.</summary>
		/// <param name="name">The name of the uniform.</param>
		public UniformAttribute(string name)
		{
			this.name = name;
		}

		private string name;

		/// <summary>Gets the name of the uniform in the shader program.</summary>
		public string Name { get { return name; } }

		/// <summary>Gets or sets the texture unit (only applies to textures).</summary>
		public int Unit { get; set; }
	}
}
