﻿// $Id: StereoVideoDisplay.cs 436 2010-10-15 16:26:38Z cr333 $
using System;
using System.Drawing;
using VideoLib.Frames;
using VideoLib.Utils;

namespace VideoLib.Sinks
{
	/// <summary>Generic video display node with support for a caption.</summary>
	public class StereoVideoDisplay : Node
	{
		/// <summary>Gets or sets the video panel.</summary>
		/// <value>The video panel.</value>
		protected IStereoVideoControl StereoVideoPanel { get; set; } // TODO: handle Disposed event properly

		/// <summary>Caption to display in this panel.</summary>
		protected string Title { get; set; }

		/// <summary>For displaying the frames per second arriving at the display.</summary>
		protected FrameRateCounter fps = new FrameRateCounter(0.5, 0.3);

		/// <summary>Human-friendly node name.</summary>
		public override string Name
		{
			get { return String.Format("{0}({1})", base.Name, Title); }
		}

		/// <summary>
		/// Initializes a new instance of the <see cref="VideoDisplay"/> class.
		/// </summary>
		/// <param name="targetControl">The target control.</param>
		/// <param name="title">The title.</param>
		public StereoVideoDisplay(IStereoVideoControl targetControl, string title)
			: base()
		{
			StereoVideoPanel = targetControl;
			StereoVideoPanel.Disposed += new EventHandler(ControlDisposed);
			Title = title;
			AddInputPins("inL", "inR");
		}

		/// <summary>
		/// Disposed event handler.
		/// </summary>
		/// <param name="sender">The sender.</param>
		/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
		void ControlDisposed(object sender, EventArgs e)
		{
			StereoVideoPanel = null;
			Status = NodeStatus.Stopped;
		}

		/// <summary>Processes a video frame.</summary>
		public override void Process()
		{
			// skip over this when not yet ready
			if (StereoVideoPanel == null)
				return;
			fps.NewFrame();

			/*// get latest frames
			Frame frameL = GetInputPin("inL").GetFrame();
			Frame frameR = GetInputPin("inR").GetFrame();

			// stop on end of stream
			if (frameL is EndOfStreamFrame || frameR is EndOfStreamFrame)
			{
				Status = NodeStatus.Finished;
				return;
			}

			// make sure they're bitmapframes
			BitmapFrame bitmapFrameL = CastFrameTo<BitmapFrame>(frameL);
			BitmapFrame bitmapFrameR = CastFrameTo<BitmapFrame>(frameR);
			*/

			var frames = GetInputFrames("inL", "inR");
			
			if (PassOnEndOfStreamFrame(frames)) 
				return;
			
			var bitmapFrames = CastFramesTo<BitmapFrame>(frames);

			AssertFrameProperties(bitmapFrames, FrameProps.Size | FrameProps.Format | FrameProps.SequenceNumber);


			// prepare caption
			string text = String.Format("{0}\nFrame: {1}\nFPS: {2:0.0}", Title, frames["inL"].SequenceNumber, fps.FPS);

			// draw the new frame
			StereoVideoPanel.Draw(bitmapFrames["inL"], bitmapFrames["inR"], text);
		}
	}
}
